@@ -3,6 +3,7 @@ package cmd
 import (
 	"bytes"
 	"encoding/json"
+	"os"
 	"os/exec"
 	"strings"
 )
@@ -21,12 +22,11 @@ func (c *Config) secretTemplateFunc(args ...string) string {
 
 	//nolint:gosec
 	cmd := exec.Command(c.Secret.Command, args...)
-	cmd.Stdin = c.stdin
-	cmd.Stderr = c.stderr
+	cmd.Stdin = os.Stdin
+	cmd.Stderr = os.Stderr
 	output, err := c.baseSystem.IdempotentCmdOutput(cmd)
 	if err != nil {
-		raiseTemplateError(newCmdOutputError(cmd, output, err))
-		return ""
+		panic(newCmdOutputError(cmd, output, err))
 	}
 
 	value := string(bytes.TrimSpace(output))
@@ -46,18 +46,16 @@ func (c *Config) secretJSONTemplateFunc(args ...string) interface{} {
 
 	//nolint:gosec
 	cmd := exec.Command(c.Secret.Command, args...)
-	cmd.Stdin = c.stdin
-	cmd.Stderr = c.stderr
+	cmd.Stdin = os.Stdin
+	cmd.Stderr = os.Stderr
 	output, err := c.baseSystem.IdempotentCmdOutput(cmd)
 	if err != nil {
-		raiseTemplateError(newCmdOutputError(cmd, output, err))
-		return nil
+		panic(newCmdOutputError(cmd, output, err))
 	}
 
 	var value interface{}
 	if err := json.Unmarshal(output, &value); err != nil {
-		raiseTemplateError(newParseCmdOutputError(c.Secret.Command, args, output, err))
-		return nil
+		panic(newParseCmdOutputError(c.Secret.Command, args, output, err))
 	}
 
 	if c.Secret.jsonCache == nil {
